@@ -34,7 +34,7 @@ class Prismalytics:
                 new_server = {
                     "name": server.name,
                     "member_count": server.member_count,
-                    "region": server.region,
+                    "region": server.region.value,
                     "bot_messages": 1
                     }
                 self.servers.append(new_server)
